@@ -1,12 +1,9 @@
 import inspect
-import logging
 import threading
 
 from ..decorators import wraps
 from ...exceptions import ResourceLocked, ResourceNotLocked
 
-logger = logging.getLogger(__name__)
-
 
 class LockedDataset:
     """
