@@ -1,5 +1,5 @@
 import ctypes
-import logging
+
 import platform
 import threading
 import typing as tp
@@ -8,8 +8,6 @@ from threading import Condition as PythonCondition
 from satella.time import measure
 from ...exceptions import ResourceLocked, WouldWaitMore
 
-logger = logging.getLogger(__name__)
-
 
 class Condition(PythonCondition):
     """
@@ -98,7 +96,6 @@ class TerminableThread(threading.Thread):
         This should block for as long as a single check will take, as termination checks take place
         between calls.
         """
-        raise NotImplementedError('Override me!')
 
     def run(self) -> None:
         """
