@@ -1,15 +1,12 @@
-import logging
 import os
 import sys
 import typing as tp
 
-from satella.coding import rethrow_as
+from satella.coding.recast_exceptions import rethrow_as
 from satella.exceptions import ConfigurationError
 from .base import BaseSource
 from .format import JSONSource
 
-logger = logging.getLogger(__name__)
-
 __all__ = [
     'EnvVarsSource', 'EnvironmentSource',
 ]
