@@ -88,7 +88,8 @@ class RendererObject(io.StringIO):
         self.write(md.name.replace('.', '_'))
         if md.labels:
             self.write('{')
-            self.write(','.join('%s="%s"' % (key, value) for key, value in md.labels.items()))
+            self.write(','.join('%s="%s"' % (
+                key, str(value).replace('\\', '\\\\').replace('"', '\\"')) for key, value in md.labels.items()))
             self.write('}')
         self.write(' %s' % (md.value, ))
         if md.timestamp is not None:
