@@ -1,4 +1,5 @@
-from .base import Metric, LeafMetric, RUNTIME, DISABLED, INHERIT, DEBUG, EmbeddedSubmetrics
+from .base import Metric, MetricLevel, LeafMetric, EmbeddedSubmetrics, DISABLED, RUNTIME, \
+    DEBUG, INHERIT
 from .cps import ClicksPerTimeUnitMetric
 from .simple import IntegerMetric, FloatMetric
 from .counter import CounterMetric
@@ -9,7 +10,8 @@ from .callable import CallableMetric
 from .summary import QuantileMetric, SummaryMetric
 from .registry import register_metric, METRIC_NAMES_TO_CLASSES
 
-__all__ = ['Metric', 'LeafMetric', 'EmbeddedSubmetrics', 'RUNTIME', 'DEBUG', 'INHERIT',
-           'DISABLED', 'ClicksPerTimeUnitMetric', 'IntegerMetric', 'FloatMetric',
+__all__ = ['Metric', 'LeafMetric', 'EmbeddedSubmetrics', 'ClicksPerTimeUnitMetric',
+           'IntegerMetric', 'FloatMetric',
            'QuantileMetric', 'register_metric', 'METRIC_NAMES_TO_CLASSES', 'SummaryMetric',
-           'HistogramMetric', 'EmptyMetric', 'LinkfailMetric', 'CallableMetric']
+           'HistogramMetric', 'EmptyMetric', 'LinkfailMetric', 'CallableMetric', 'MetricLevel',
+           'INHERIT', 'DEBUG', 'RUNTIME', 'DISABLED']
