@@ -1,4 +1,3 @@
-import logging
 import typing as tp
 
 from .base import EmbeddedSubmetrics
@@ -7,9 +6,6 @@ from .registry import register_metric
 from ..data import MetricData, MetricDataCollection
 
 
-logger = logging.getLogger(__name__)
-
-
 class SimpleMetric(EmbeddedSubmetrics):
     __slots__ = ('data', )
 
